@@ -15,7 +15,8 @@ client_global = None
 _tablename = None
 
 # [0621]load tree relationship file
-df_tree = pd.read_csv("uhafOBO_0621.csv")
+cpath = os.path.realpath(__file__)
+df_tree = pd.read_csv(cpath.split(os.path.basename(__file__))[0]+"uhafOBO_0621.csv")
 
 ####### Preprocessing functions #######
 
